/*!
 *****************************************************************************
 *
 * @File       memtestimport.c
 * ---------------------------------------------------------------------------
 *
 * Copyright (c) Imagination Technologies Ltd.
 * 
 * The contents of this file are subject to the MIT license as set out below.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
 * THE SOFTWARE.
 * 
 * Alternatively, the contents of this file may be used under the terms of the 
 * GNU General Public License Version 2 ("GPL")in which case the provisions of
 * GPL are applicable instead of those above. 
 * 
 * If you wish to allow use of your version of this file only under the terms 
 * of GPL, and not to allow others to use your version of this file under the 
 * terms of the MIT license, indicate your decision by deleting the provisions 
 * above and replace them with the notice and other provisions required by GPL 
 * as set out in the file called "GPLHEADER" included in this distribution. If 
 * you do not delete the provisions above, a recipient may use your version of 
 * this file under the terms of either the MIT license or GPL.
 * 
 * This License is also included in this distribution in the file called 
 * "MIT_COPYING".
 *
 *****************************************************************************/

#include <sys/types.h>
#include <sys/stat.h>
#include <sys/mman.h>
#include <sys/ioctl.h>
#include <fcntl.h>
#include <stdio.h>
#include <unistd.h>

#include <vxd.h>
#include <dmabuf_exporter.h>

#define HEAP_ID 2
#define BUFF_SIZE 65535
#define VIRT_ADDR 0x1042000

int main(int argc, char **argv)
{
    int vxd_fd;
    int buff_id;
    int stream_id;
    int dmadev_fd;
    int dmabuf_fd;
    int ret;

    vxd_fd = open("/dev/vxd0", O_RDWR);
    if (vxd_fd < 0) {
        perror("open");
        return 1;
    }
    printf("fd %d\n", vxd_fd);

    dmadev_fd = open("/dev/dmabuf", O_RDWR);
    if (dmadev_fd < 0) {
	perror("open dmabuf");
	return 1;
    }
    printf("dbabuf device fd : %d\n", dmadev_fd);

    if (ioctl(dmadev_fd, DMABUF_IOCTL_CREATE, BUFF_SIZE)) {
	perror("ioctl DMABUF_IOCTL_CREATE");
	return 1;
    }
    printf("dbabuf buffer created size %d\n", BUFF_SIZE);

    dmabuf_fd = ioctl(dmadev_fd, DMABUF_IOCTL_EXPORT, 0);
    if (dmabuf_fd < 0) {
	printf("error exporting\n");
	return 1;
    }
    printf("dbabuf export fd : %d\n", dmabuf_fd);

    struct vxd_import_data data = {
	.heap_id = HEAP_ID,
	.size = BUFF_SIZE,
	.attributes = 0,
	.buf_fd = dmabuf_fd,
    };

    ret = ioctl(vxd_fd, VXD_IOCTL_IMPORT, (long)&data);
    if (ret) {
	perror("ioctl import");
	return 1;
    }
    buff_id = data.buf_id;
    printf("imported buffer as %d\n", buff_id);

    if (1) {
        void *ptr;
	int i;

        ptr = mmap(NULL, BUFF_SIZE,
                   PROT_READ | PROT_WRITE, MAP_SHARED, vxd_fd,
                   getpagesize() * buff_id);
        if (ptr == MAP_FAILED) {
            perror("mmap");
            return 1;
        }
        printf("mapped to %p\n", ptr);

	for (i = 0; getpagesize() * i < BUFF_SIZE; i++) {
	    int *iptr = (int *)((uintptr_t)ptr + getpagesize() * i);
	    int val = (0xbeef << 16) | i;

	    printf("write [%p] = %x\n", iptr, val);
	    *iptr = val;
	}
	for (i = 0; getpagesize() * i < BUFF_SIZE; i++) {
	    int *iptr = (int *)((uintptr_t)ptr + getpagesize() * i);
	    int val = (0xbeef << 16) | i;

	    printf("read [%p] = %x [expected %x]\n", iptr, *iptr, val);
	    if (*iptr != val)
		return 1;
	}
	sleep(3);
    }

    {
        struct vxd_create_stream_data data = {
	    .stream_type = VXD_STR_TYPE_NON_SECURE,
	};

        ret = ioctl(vxd_fd, VXD_IOCTL_STREAM_CREATE, (long)&data);
        if (ret) {
            perror("stream create");
            return 1;
        }
        stream_id = data.stream_id;
    }
    printf("stream id %d\n", stream_id);

    if (1) {
        struct vxd_map_data data = {
            .stream_id = stream_id,
            .buf_id = buff_id,
            .virt_addr = VIRT_ADDR,
        };

        ret = ioctl(vxd_fd, VXD_IOCTL_VXD_MAP, (long)&data);
        if (ret) {
            perror("ioctl vxd map");
            return 1;
        }
	printf("mapped vxd buffer %d\n", buff_id);
    }
    sleep(3);

    if (1) {
        struct vxd_unmap_data data = {
            .stream_id = stream_id,
            .buf_id = buff_id,
        };

        ret = ioctl(vxd_fd, VXD_IOCTL_VXD_UNMAP, (long)&data);
        if (ret) {
            perror("ioctl vxd unmap");
            return 1;
        }
	printf("unmapped buffer %d\n", buff_id);
    }

    if (1) {
        struct vxd_free_data data = { buff_id };

        ret = ioctl(vxd_fd, VXD_IOCTL_FREE, (long)&data);
        if (ret) {
            perror("ioctl free");
            return 1;
        }
    }

    if (1) {
        struct vxd_destroy_stream_data data;

        data.stream_id = stream_id;
        ret = ioctl(vxd_fd, VXD_IOCTL_STREAM_DESTROY, (long)&data);
        if (ret) {
            perror("stream destory");
            return 1;
        }
    }

    return 0;
}
