/*!
 *****************************************************************************
 *
 * @File       helpers.h
 * ---------------------------------------------------------------------------
 *
 * Copyright (c) Imagination Technologies Ltd.
 * 
 * The contents of this file are subject to the MIT license as set out below.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
 * THE SOFTWARE.
 * 
 * Alternatively, the contents of this file may be used under the terms of the 
 * GNU General Public License Version 2 ("GPL")in which case the provisions of
 * GPL are applicable instead of those above. 
 * 
 * If you wish to allow use of your version of this file only under the terms 
 * of GPL, and not to allow others to use your version of this file under the 
 * terms of the MIT license, indicate your decision by deleting the provisions 
 * above and replace them with the notice and other provisions required by GPL 
 * as set out in the file called "GPLHEADER" included in this distribution. If 
 * you do not delete the provisions above, a recipient may use your version of 
 * this file under the terms of either the MIT license or GPL.
 * 
 * This License is also included in this distribution in the file called 
 * "MIT_COPYING".
 *
 *****************************************************************************/

#ifndef HELPERS_H
#define HELPERS_H

#define VXD_INVALID_ID -1

#define VXD_MAX_CTXS 10
#define VXD_MAX_CTX_STREAMS 100
#define VXD_MAX_BUFS 1024

#define VXD_NONE_LABEL "N"

#define PATT_TYPE_ZERO 0
#define PATT_TYPE_INC_UINT 1

struct vxd_buffer {
	int id;
	size_t size;
	void *ptr;
	uint32_t virt_addr;
};

struct vxd_util_ctx {
	int fd;
	int cur_str_id;
	int cur_buf_id;
	int heap_id;
	int str_ids[VXD_MAX_CTX_STREAMS];
	struct vxd_buffer bufs[VXD_MAX_BUFS];
};

#define VXD_CUR_STR_ID(CTX) ((CTX)->str_ids[(CTX)->cur_str_id])


/* Common operations */
int vxd_open(int dev_id);
int vxd_close(int fd);
int vxd_ioctl(int fd, unsigned int code, void *data);
int vxd_send_msg(int fd, uint32_t *buf, size_t count);
int vxd_recv_msg(int fd, uint32_t *buf, size_t count);
int vxd_parse_ints(const char *arg, size_t alloc_prefix,
		uint32_t **res, uint8_t **none);
const char* vxd_get_arg_no(int arg_no, const char *src);

#endif /* HELPERS_H */
