/*!
 *****************************************************************************
 *
 * @File       vxd_util.h
 * ---------------------------------------------------------------------------
 *
 * Copyright (c) Imagination Technologies Ltd.
 * 
 * The contents of this file are subject to the MIT license as set out below.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
 * THE SOFTWARE.
 * 
 * Alternatively, the contents of this file may be used under the terms of the 
 * GNU General Public License Version 2 ("GPL")in which case the provisions of
 * GPL are applicable instead of those above. 
 * 
 * If you wish to allow use of your version of this file only under the terms 
 * of GPL, and not to allow others to use your version of this file under the 
 * terms of the MIT license, indicate your decision by deleting the provisions 
 * above and replace them with the notice and other provisions required by GPL 
 * as set out in the file called "GPLHEADER" included in this distribution. If 
 * you do not delete the provisions above, a recipient may use your version of 
 * this file under the terms of either the MIT license or GPL.
 * 
 * This License is also included in this distribution in the file called 
 * "MIT_COPYING".
 *
 *****************************************************************************/

#ifndef VXD_UTIL_H
#define VXD_UTIL_H

#define VXD_DEV_PATH "/dev/vxd%d"

#define vxd_err(...) fprintf(stderr, __VA_ARGS__)
#define vxd_dbg(...) fprintf(stdout, __VA_ARGS__)

#define VXD_ACTION_DECLR(NAME) \
	void vxd_action_##NAME##_help(const char *); \
	int vxd_action_##NAME##_exec(const char *); \

typedef void (*vxd_action_help_fn)(const char *name);
typedef int (*vxd_exec_action_fn)(const char *arg);

struct vxd_action {
	int no;
	const char * name;
	vxd_action_help_fn help_fn;
	vxd_exec_action_fn exec_fn;
};

VXD_ACTION_DECLR(open);
VXD_ACTION_DECLR(close);
VXD_ACTION_DECLR(get_props);
VXD_ACTION_DECLR(str_creat);
VXD_ACTION_DECLR(str_destr);
VXD_ACTION_DECLR(str_switch);
VXD_ACTION_DECLR(send_msg);
VXD_ACTION_DECLR(recv_msg);
VXD_ACTION_DECLR(alloc);
VXD_ACTION_DECLR(free);
VXD_ACTION_DECLR(vxd_map);
VXD_ACTION_DECLR(vxd_unmap);
VXD_ACTION_DECLR(mmap);
VXD_ACTION_DECLR(munmap);
VXD_ACTION_DECLR(fill_buf);
VXD_ACTION_DECLR(dump_buf);
VXD_ACTION_DECLR(popu_buf);
VXD_ACTION_DECLR(verif_buf);

/* Application specific functions */
void vxd_util_init();


#endif /* VXD_UTIL_H */
